package demo.usage.maps;

import java.util.ArrayList;

import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Point;
import android.graphics.Paint.*;
import android.graphics.drawable.Drawable;

import com.google.android.maps.ItemizedOverlay;
import com.google.android.maps.MapView;
import com.google.android.maps.OverlayItem;

public class MyItemizedOverlay extends ItemizedOverlay<OverlayItem> {
	
	private ArrayList<OverlayItem> overlays = new ArrayList<OverlayItem>();
	private boolean drawLines = false;	
	Paint p = new Paint();
	Path line = new Path();
	Point startPoint = new Point(),
		  middlePoint = new Point();
	

	// -------------------- Konstruktorok -------------------------
	public MyItemizedOverlay(Drawable defaultMarker) {
		super(boundCenter(defaultMarker));
		// Hogy nagyin szpen rajzoljunk
		p.setDither(true);
		p.setColor(Color.BLUE);
		p.setStyle(Style.STROKE);
		p.setStrokeJoin(Join.ROUND);
		p.setStrokeCap(Cap.ROUND);
		p.setStrokeWidth(3);	
		p.setAntiAlias(true);		// Nehogy felsrcse az jjunkat :)
		
		// Azrt kell, mert elfordulhat hogy res a lista.
		// Ha pedig res, akkor soha nem volt populate();
		populate();	
	}	
	
	// -------------- Implementland metdusok -------------------
	public void addOverlay(OverlayItem overlay){
		overlays.add(overlay);
		// rtestsk hogy megvltozott a pontok szma
		populate();
	}
	public void justOneOverlay(OverlayItem newOverlay){
		overlays.clear();
		addOverlay(newOverlay);				
	}
	@Override
	protected OverlayItem createItem(int i) {
		return overlays.get(i);
	}
	@Override
	public int size() {
		return overlays.size();
	}
	
	// Opcionlis metdusok ---------------------------------------
	public boolean isDrawLines() {
		return drawLines;
	}
	public void setDrawLines(boolean drawLines) {
		this.drawLines = drawLines;		
	}	
	
	// -------------------- RAJZ, ha szksges ---------------------
	// 					    Overlay kpessge	
	
	@Override
	public void draw(Canvas canvas, MapView mapView, boolean shadow) {		
		
		if(drawLines && overlays.size() > 0){
			
			// Projekci hasznlata, mivel a rajzols koordintja fgg a trkp pozicitl s a zoom szinttl			
			mapView.getProjection().toPixels(overlays.get(0).getPoint(), startPoint);
			
			// Az els pont hozzadsa a Path-hoz = Kezdpont
			line.reset();							// reset() nem pedig j pldny --> gyorst
			line.moveTo(startPoint.x, startPoint.y);
			
			// Vgig megynk a pontokon s hozzadjuk a Path-hoz mert vonalat szeretnnk rajzolni
			for(OverlayItem i : overlays){				
				mapView.getProjection().toPixels(i.getPoint(), middlePoint);	// Projectio most is kell
				line.lineTo(middlePoint.x, middlePoint.y);
			}
			
			// s akkor a lnyeg, a rajzols :)
			canvas.drawPath(line, p);			
		}
		
		super.draw(canvas, mapView, shadow);
		 
	}

}
